# make_install_disk_image

`make_install_disk_image` は 対象製品のインストールディスクイメージを作成できます。
予め実行に必要なファイルを用意する必要があります。
詳細は後述の使用方法をご確認ください。

## 対象製品

- Armadillo-IoT G3
- Armadillo-IoT G3 M1
- Armadillo-IoT G3 W2
- Armadillo-IoT G3L
- Armadillo-X1
- Degu Gateway G3

## 使用方法

`build.sh` を実行することでインストールディスクイメージを作成することができます。
管理者権限が必要なため、必ず`sudo`をつけて実行する必要があります。

`sudo build.sh` とコマンド実行することで ツールの使用方法を確認することができます。

```
[ATDE ~/make_install_disk_image]$ sudo build.sh
Install Disk Image Build Script v1.4.0

Usage:
  sudo ./build.sh BOARD UBOOT KERNEL DTB USERLAND [BOOTSCR]
  sudo ./build.sh -f CONFIG_FILE
  sudo ./build.sh -r BOARD UBOOT KERNEL DTB USERLAND RECOVERY RECOVERY_DTB RECOVERY_BOOTSCR [BOOTSCR]

  -f: use config file
  -r: use Recovery image

  BOARD: x1/iotg3/iotg3_m1/iotg3_w2/iotg3l/degugw_iotg3_m1
  UBOOT: u-boot image
  KERNEL: uImage
  DTB: Device Tree Blob image
  USERLAND: Debian userland archive
  RECOVERY: Recovery uImage
  RECOVERY_DTB: Recovery Device Tree Blob image
  RECOVERY_BOOTSCR: Recovery u-boot script
  BOOTSCR: u-boot script
```

インストールディスクイメージに必要なファイルを用意し、引数で指定することで作成が可能です。  
引数とイメージファイルの対応を以下に記載します。

|引数               |説明                                           |ファイル名称
|-------------------|-----------------------------------------------|-------------
|BOARD              |対象のボード製品                               |-
|UBOOT              |ブートローダーイメージ                         |u-boot-x1-[version].bin
|KERNEL             |Linux カーネルイメージ                         |uImage-x1-[version]
|DTB                |Device Tree Blob                               |armadillo_[board_name]-[version].dtb
|USERLAND           |Debian GNU/Linux ルートファイルシステム        |debian-[debian_version]-armhf_[board_name]_[version].tar.gz
|RECOVERY           |node-eye リカバリー用 Linux カーネルイメージ   |uImage.recovery
|RECOVERY_DTB       |node-eye リカバリー用 Device Tree Blob         |armadillo_[board_name].dtb.recovery
|RECOVERY_BOOTSCR   |node-eye リカバリー用 U-Boot ブートスクリプト  |boot.scr.recovery
|BOOTSCR            |U-Boot ブートスクリプト(オプション)            |boot.scr

build.sh のオプション詳細は以下です:

- -f CONFIG_FILE  
    build.sh 実行時に必要な引数を CONFIG_FILE に記載し、-f オプションと共に CONFIG_FILE を引数に指定することでインストールディスクイメージの作成が可能です。
    CONFIG_FILE は任意のファイル名を指定可能です。
    CONFIG_FILE はサンプルとして `sample_config_file`を用意しています。
    ```
    BOARD=""
    UBOOT=""
    KERNEL=""
    DTB=""
    USERLAND=""
    BOOTSCR=""
    RECOVERY=""
    RECOVERY_DTB=""
    RECOVERY_BOOTSCR=""
    ```
    node-eye リカバリー用イメージを必要としない場合、RECOVERY RECOVERY_DTB RECOVERY_BOOTSCR の記載をする必要はありません。

- -r  
    -r オプションの他、RECOVERY RECOVERY_DTB RECOVERY_BOOTSCR を追加で 引数に指定することで node-eye のリカバリーイメージを書き込むことができます。
